@@ -1,6 +1,6 @@
-CodeMirrorConfig.stylesheet = "/python_field/css/pythoncolors.css";
-CodeMirrorConfig.path = "/python_field/js/";
-CodeMirrorConfig.parserfile = "/python_field/js/parsepython.js";
+CodeMirrorConfig.stylesheet = "/static/python_field/css/pythoncolors.css";
+CodeMirrorConfig.path = "/static/python_field/js/";
+CodeMirrorConfig.parserfile = "/static/python_field/js/parsepython.js";
 CodeMirrorConfig.height = "dynamic";
 CodeMirrorConfig.indentUnit = 4;
 CodeMirrorConfig.lineNumbers = true;
